@@ -358,5 +358,13 @@ on_automatic_loan_repayment_activate   (GtkMenuItem     *menuitem,
 void
 on_menu_news_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
-#endif
 
+
+void
+on_menu_edit_name_activate             (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_player_menu_edit_name_activate      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+#endif
