@@ -37,8 +37,13 @@ enum Counters
     COUNT_LEAGUE_ID,
     COUNT_FIX_ID,
     COUNT_LG_COMM_ID,
+    COUNT_NEWS_TITLE_ID,
+    COUNT_NEWS_SUBTITLE_ID,
+    COUNT_NEWS_ARTICLE_ID,
     COUNT_SHOW_DEBUG,
     COUNT_HINT_NUMBER,
+    COUNT_NEWS_SHOWN,
+    COUNT_NEW_NEWS,
     COUNT_END
 };
 
