@@ -48,7 +48,7 @@ misc_print_error(GError **error, gboolean abort_program)
     if(*error == NULL)
 	return;
     
-    g_warning("error message: %s\n", (*error)->message);
+    debug_print_message("error message: %s\n", (*error)->message);
     g_error_free(*error);
     *error = NULL;
 
@@ -112,7 +112,7 @@ misc_separate_strings(gchar *string)
 
     if(start == strlen(string))
     {
-	g_warning("misc_separate_strings: input string contains only white spaces\n");
+	debug_print_message("misc_separate_strings: input string contains only white spaces\n");
 	return string_array;
     }
 
@@ -532,33 +532,13 @@ misc_string_assign(gchar **string, const gchar *contents)
 void
 misc_string_choose_random(gchar *string)
 {
-   const gchar STR_SEP = '|';
-   gint i = 0;
    gint count = 1;
-   const gchar* start;
+   gchar **array;
    
-   for (i = 0; string[i]; i++)
-      count += (string[i] == STR_SEP);
-
-   if (count == 1)
-      return;
-      
-   count = math_rndi(0, count - 1) + 1;
-   start = string;
-   for (i = 0; string[i]; i++)
-      if (string[i] == STR_SEP)
-      {
-         count--;
-	 if (count == 1)
-	    start = string + i + 1;
-	 else if (!count)
-	 {
-	    string[i] = '\0';
-	    break;
-         }
-      }
-
-   strcpy(string, start);
+   array = g_strsplit(string, "|", -1);
+   count = g_strv_length(array);
+   count = math_rndi(0, count - 1);
+   strcpy(string, array[count]);
 }
 
 /** Replace a token in a string by another string. 
@@ -616,7 +596,7 @@ misc_string_replace_expressions(gchar *string)
 
 	if(occurrence2 == NULL)
 	{
-	    g_warning("misc_string_replace_expressions: no matching ] found.");
+	    debug_print_message("misc_string_replace_expressions: no matching ] found.");
 	    return;
 	}
 
@@ -792,3 +772,43 @@ misc_string_replace_all_tokens(GPtrArray **token_rep,
 
     return (g_strrstr(dest, "_") == NULL);
 }
+
+/* Alphabetic compare function. */
+gint
+misc_alphabetic_compare(gconstpointer a, gconstpointer b)
+{
+    const gchar *string[2] = {(const gchar*)a,
+                              (const gchar*)b};
+    gchar alphabet[26] = {'a','b','c','d','e','f','g',
+                          'h','i','j','k','l','m','n',
+                          'o','p','q','r','s','t','u',
+                          'v','w','x','y','z'};
+    gint len[2] = {strlen(string[0]), strlen(string[1])};
+    gint maxlen = MIN(len[0], len[1]);
+    gint letter[2];
+    gint i, j, k;
+
+    for(i = 0; i < maxlen; i++)
+    {
+        for(k = 0; k < 2; k++)
+        {
+            letter[k] = 0;
+            for(j = 0; j < 26; j++)
+                if(string[k][i] == alphabet[j])
+                {
+                    letter[k] = j;
+                    break;
+                }
+        }
+        
+        if(letter[0] < letter[1])
+            return -1;
+        else if(letter[0] > letter[1])
+            return 1;
+    }
+
+    if(len[0] != len[1])
+        return 1 - 2 * (len[0] < len[1]);
+
+    return 0;
+}
