@@ -138,7 +138,7 @@ start_new_season(void)
     {
 	for(i=0;i<users->len;i++)
 	{
-	    sprintf(buf, "%d", team_get_league_rank(usr(i).tm));
+	    sprintf(buf, "%d", team_get_league_rank(usr(i).tm, -1));
 	    user_history_add(&usr(i), USER_HISTORY_END_SEASON,
 			     usr(i).tm->name, 
 			     league_cup_get_name_string(usr(i).tm->clid), 
@@ -490,7 +490,7 @@ end_week_round_update_fixtures(void)
     for(i=0;i<acps->len;i++)
 	if(acp(i)->next_fixture_update_week <= week &&
 	   acp(i)->next_fixture_update_week_round <= week_round)
-	    fixture_update(acp(i));
+	    fixture_update(acp(i));            
 
     for(i=0;i<ligs->len;i++)
 	if(query_league_active(&lig(i)) && week == 
