@@ -124,7 +124,7 @@ xml_loadsave_cup_start_element (GMarkupParseContext *context,
 	new_round = cup_round_new();
 
      if(!valid_tag)
-	g_warning("xml_loadsave_cup_start_element: unknown tag: %s; I'm in state %d\n",
+	debug_print_message("xml_loadsave_cup_start_element: unknown tag: %s; I'm in state %d\n",
 		  element_name, state);
 }
 
@@ -203,7 +203,7 @@ xml_loadsave_cup_end_element    (GMarkupParseContext *context,
 	    tag == TAG_CUP_ROUND_TWO_MATCH_WEEK)
 	state = TAG_CUP_ROUND;
     else if(tag != TAG_CUP)
-	g_warning("xml_loadsave_cup_end_element: unknown tag: %s; I'm in state %d\n",
+	debug_print_message("xml_loadsave_cup_end_element: unknown tag: %s; I'm in state %d\n",
 		  element_name, state);
 }
 
@@ -370,7 +370,7 @@ xml_loadsave_cup_read(const gchar *filename, Cup *cup)
 
     if(!g_file_get_contents(filename, &file_contents, &length, &error))
     {
-	g_warning("xml_loadsave_cup_read: error reading file %s\n", filename);
+	debug_print_message("xml_loadsave_cup_read: error reading file %s\n", filename);
 	misc_print_error(&error, TRUE);
     }
 
@@ -385,7 +385,7 @@ xml_loadsave_cup_read(const gchar *filename, Cup *cup)
     }
     else
     {
-	g_warning("xml_loadsave_cup_read: error parsing file %s\n", filename);
+	debug_print_message("xml_loadsave_cup_read: error parsing file %s\n", filename);
 	misc_print_error(&error, TRUE);
     }
 
