@@ -97,7 +97,7 @@ xml_loadsave_misc_start_element (GMarkupParseContext *context,
     }
 
     if(!valid_tag)
-	g_warning("xml_loadsave_misc_start_element: unknown tag: %s; I'm in state %d\n",
+	debug_print_message("xml_loadsave_misc_start_element: unknown tag: %s; I'm in state %d\n",
 		  element_name, state);
 }
 
@@ -142,7 +142,7 @@ xml_loadsave_misc_end_element    (GMarkupParseContext *context,
 	    oddidx++;
     }
     else if(tag != TAG_MISC)
-	g_warning("xml_loadsave_misc_end_element: unknown tag: %s; I'm in state %d\n",
+	debug_print_message("xml_loadsave_misc_end_element: unknown tag: %s; I'm in state %d\n",
 		  element_name, state);
 }
 
@@ -218,7 +218,7 @@ xml_loadsave_misc_read(const gchar *dirname, const gchar *basename)
 
     if(!g_file_get_contents(file, &file_contents, &length, &error))
     {
-	g_warning("xml_loadsave_misc_read: error reading file %s\n", file);
+	debug_print_message("xml_loadsave_misc_read: error reading file %s\n", file);
 	misc_print_error(&error, TRUE);
     }
 
@@ -235,7 +235,7 @@ xml_loadsave_misc_read(const gchar *dirname, const gchar *basename)
     }
     else
     {
-	g_warning("xml_loadsave_misc_read: error parsing file %s\n", file);
+	debug_print_message("xml_loadsave_misc_read: error parsing file %s\n", file);
 	misc_print_error(&error, TRUE);
     }
 }
