@@ -89,7 +89,7 @@ xml_loadsave_season_stats_start_element (GMarkupParseContext *context,
 	new_season_stat = stat_season_stat_new(-1);
 
     if(!valid_tag)
-	g_warning("xml_loadsave_season_stats_start_element: unknown tag: %s; I'm in state %d\n",
+	debug_print_message("xml_loadsave_season_stats_start_element: unknown tag: %s; I'm in state %d\n",
 		  element_name, state);
 }
 
@@ -129,7 +129,7 @@ xml_loadsave_season_stats_end_element    (GMarkupParseContext *context,
 	    tag == TAG_CHAMP_STAT_CL_NAME)
 	state = TAG_CHAMP_STAT;
     else if(tag != TAG_SEASON_STATS)
-	g_warning("xml_loadsave_season_stats_end_element: unknown tag: %s; I'm in state %d\n",
+	debug_print_message("xml_loadsave_season_stats_end_element: unknown tag: %s; I'm in state %d\n",
 		  element_name, state);
 }
 
@@ -191,7 +191,7 @@ xml_loadsave_season_stats_read(const gchar *dirname, const gchar *prefix)
 
     if(!g_file_get_contents(filename, &file_contents, &length, &error))
     {
-	g_warning("xml_loadsave_season_stats_read: error reading file %s\n", filename);
+	debug_print_message("xml_loadsave_season_stats_read: error reading file %s\n", filename);
 	misc_print_error(&error, TRUE);
     }
 
@@ -206,7 +206,7 @@ xml_loadsave_season_stats_read(const gchar *dirname, const gchar *prefix)
     }
     else
     {
-	g_warning("xml_loadsave_season_stats_read: error parsing file %s\n", filename);
+	debug_print_message("xml_loadsave_season_stats_read: error parsing file %s\n", filename);
 	misc_print_error(&error, TRUE);
     }
 }
